@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 import sys
 from abc import ABCMeta, abstractmethod
 
@@ -601,7 +602,7 @@ def describe_value_multiline(x):
         else:
             return x.__repr__()
     else:
-        if isinstance(x, str):
+        if isinstance(x, six.string_types):
             if x == '': return "''"
             return x
         # XXX: this does not represent strings
@@ -618,8 +619,8 @@ def describe_value_multiline(x):
             desc = 'Instance of %s.' % class_name
             try:
                 # This fails for classes
-                final = desc + '\n' + x.__repr__()
-            except:
-                final = desc + '\n' + str(x)
+                final = "{}\n{}".format(desc, x.__repr__())
+            except: # XXX
+                final = "%s\n%s" % (desc, x)
 
             return final
