@@ -6,6 +6,8 @@ from .strings import *
 from .lists import List
 from .seq import Seq
 from .tuple import Tuple
+from .collection import Collection
+from .datetime_tz import DatetimeWithTz
 from .dicts import Dict
 from .map import Map
 from .sets import *
@@ -35,4 +37,4 @@ from .extensions import (identifier_expression, identifier_contract,
 from .isinstance_imp import *
 from .scoped_variables import scoped_variables_ref
 
-from .miscellaneous_aliases import *
+from .miscellaneous_aliases import *
\ No newline at end of file
