@@ -1,4 +1,4 @@
-from ...test_registrar import syntax_fail, good, fail, semantic_fail
+from contracts.test_registrar import syntax_fail, good, fail, semantic_fail
 
 from . import dummy_tc
 from . import separate_context_tc
@@ -14,10 +14,11 @@ from . import variables_tc
 from . import simple_values_tc
 from . import map_tc
 from . import seq_tc
+from . import collection_tc
 from . import attr_tc
 from . import files_tc
 
-from . import isinstance_tc 
+from . import isinstance_tc
 
 from . import extensions_tc
 
